"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const path_1 = require("path");
const pgp = require("pg-promise");
class Run extends command_1.Command {
    async run() {
        const { args: { path }, flags: { connectionString } } = this.parse(Run);
        if (!connectionString && !process.env.DATABASE_URL) {
            this.error("No connection string provided.");
        }
        const pgConfig = pgp();
        const db = pgConfig({
            connectionString: connectionString || process.env.DATABASE_URL
        });
        const sql = new pgp.QueryFile(path_1.join(process.cwd(), path), { minify: true });
        this.log("Running...");
        try {
            await db.query(sql);
        }
        catch (err) {
            this.log(err);
            this.error(`Could not run file.`);
        }
        this.log("Finished running SQL file.");
        await db.$pool.end();
    }
}
Run.description = "Run .sql files";
Run.examples = [
    `$ migr8r run path/to/file.sql
Running...
`
];
Run.args = [{ name: "path" }];
Run.flags = {
    connectionString: command_1.flags.string({ char: "c" }),
    help: command_1.flags.help({ char: "h" })
};
exports.default = Run;
